var servicecom_1_1sun_1_1star_1_1text_1_1Text =
[
    [ "com::sun::star::container::XEnumerationAccess", "servicecom_1_1sun_1_1star_1_1text_1_1Text.html#a129dd133e3d7ef2600cb122d60282288", null ],
    [ "XRelativeTextContentInsert", "servicecom_1_1sun_1_1star_1_1text_1_1Text.html#ab99abc02a16cd0caf27d93d51a2fe58b", null ],
    [ "XText", "servicecom_1_1sun_1_1star_1_1text_1_1Text.html#a949976d4e140fd1797c53c05aeb8a292", null ],
    [ "XTextRangeCompare", "servicecom_1_1sun_1_1star_1_1text_1_1Text.html#ab069206253abb6cf1456a2adbaf1ef15", null ],
    [ "XTextRangeMover", "servicecom_1_1sun_1_1star_1_1text_1_1Text.html#ac04515dde5f83999b3897ce559045fb3", null ],
    [ "EndRedline", "servicecom_1_1sun_1_1star_1_1text_1_1Text.html#a3458292f12eca6571ed5a23872e6fb55", null ],
    [ "StartRedline", "servicecom_1_1sun_1_1star_1_1text_1_1Text.html#a17f85708feaec394a5c5200f24a44de0", null ]
];